@@ -47,7 +47,7 @@ def main():
     components_file = args.components
 
     fai = pysam.FastaFile(components_file)
-    agp = AGPFile(agp_file)
+    agp = AGPFile(agp_file, mode="r")
 
     # Iterate over the lines of the AGP file
     prev_obj = None
@@ -72,6 +72,7 @@ def main():
 
     # End the FASTA file with a newline
     sys.stdout.write("\n")
+    fai.close()
 
 
 if __name__ == "__main__":
