@@ -34,7 +34,7 @@ import pysam
 import numpy as np
 from intervaltree import IntervalTree
 
-from ragtag_utilities.utilities import log, run_o, get_ragtag_version
+from ragtag_utilities.utilities import log, run_oae, get_ragtag_version
 from ragtag_utilities.AlignmentReader import PAFReader
 from ragtag_utilities.ContigAlignment import ContigAlignment
 from ragtag_utilities.AGPFile import AGPFile
@@ -259,12 +259,12 @@ def write_breaks(out_file, query_file, ctg_breaks, overwrite, remove_suffix):
         else:
             log("Overwriting pre-existing file: " + out_file)
 
-    x = pysam.FastaFile(query_file)
-    all_q_seqs = sorted(x.references)
-    agp = AGPFile(out_file, "w")
+    fai = pysam.FastaFile(query_file)
+    all_q_seqs = sorted(fai.references)
+    agp = AGPFile(out_file, mode="w")
 
-    agp.add_comment("## agp-version 2.1")
-    agp.add_comment("# AGP created by RagTag")
+    agp.add_pragma()
+    agp.add_comment("# AGP created by RagTag {}".format(get_ragtag_version()))
 
     for q in all_q_seqs:
 
@@ -274,17 +274,17 @@ def write_breaks(out_file, query_file, ctg_breaks, overwrite, remove_suffix):
             # Add suffix to query header, unless otherwise requested
             unchanged_comp_header = q
             if not remove_suffix:
-                unchanged_comp_header = q + ":0" + "-" + str(x.get_reference_length(q)) + "(+)"
+                unchanged_comp_header = q + ":0" + "-" + str(fai.get_reference_length(q)) + "(+)"
 
             agp.add_seq_line(
                     q,
                     "1",
-                    str(x.get_reference_length(q)),
+                    str(fai.get_reference_length(q)),
                     "1",
                     "W",
                     unchanged_comp_header,
                     "1",
-                    str(x.get_reference_length(q)),
+                    str(fai.get_reference_length(q)),
                     "+"
             )
         else:  # This query sequence was broken
@@ -310,35 +310,37 @@ def write_breaks(out_file, query_file, ctg_breaks, overwrite, remove_suffix):
             agp.add_seq_line(
                     q,
                     str(start+1),
-                    str(x.get_reference_length(q)),
+                    str(fai.get_reference_length(q)),
                     str(pid),
                     "W",
-                    q + ":" + str(start) + "-" + str(x.get_reference_length(q)) + "(+)",
+                    q + ":" + str(start) + "-" + str(fai.get_reference_length(q)) + "(+)",
                     "1",
-                    str(x.get_reference_length(q)-start),
+                    str(fai.get_reference_length(q)-start),
                     "+"
             )
 
     log("Writing: " + out_file)
     agp.write()
+    fai.close()
 
 
 def main():
     parser = argparse.ArgumentParser(description='Reference-guided misassembly correction', usage="ragtag.py correct <reference.fa> <query.fa>")
 
+    parser.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (uncompressed or bgzipped)")
+    parser.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (uncompressed or bgzipped)")
+
     cor_options = parser.add_argument_group("correction options")
-    cor_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (can be uncompressed or bgzipped)")
-    cor_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (can be uncompressed or bgzipped)")
     cor_options.add_argument("-f", metavar="INT", type=int, default=1000, help="minimum unique alignment length [1000]")
     cor_options.add_argument("--remove-small", action="store_true", default=False, help="remove unique alignments shorter than -f")
     cor_options.add_argument("-q", metavar="INT", type=int, default=10, help="minimum mapq (NA for Nucmer alignments) [10]")
     cor_options.add_argument("-d", metavar="INT", type=int, default=100000, help="alignment merge distance [100000]")
     cor_options.add_argument("-b", metavar="INT", type=int, default=5000, help="minimum break distance from contig ends [5000]")
-    cor_options.add_argument("-e", metavar="<exclude.txt>", type=str, default="", help="list of reference headers to ignore")
-    cor_options.add_argument("-j", metavar="<skip.txt>", type=str, default="", help="list of query headers to leave uncorrected")
+    cor_options.add_argument("-e", metavar="<exclude.txt>", type=str, default="", help="list of reference headers to ignore [null]")
+    cor_options.add_argument("-j", metavar="<skip.txt>", type=str, default="", help="list of query headers to leave uncorrected [null]")
     cor_options.add_argument("--inter", action="store_true", default=False, help="only break misassemblies between reference sequences")
     cor_options.add_argument("--intra", action="store_true", default=False, help="only break misassemblies within reference sequences")
-    cor_options.add_argument("--gff", metavar="<features.gff>", type=str, default="", help="don't break sequences within gff intervals")
+    cor_options.add_argument("--gff", metavar="<features.gff>", type=str, default="", help="don't break sequences within gff intervals [null]")
 
     io_options = parser.add_argument_group("input/output options")
     io_options.add_argument("-o", metavar="PATH", type=str, default="ragtag_output", help="output directory [./ragtag_output]")
@@ -355,9 +357,9 @@ def main():
 
     val_options = parser.add_argument_group("validation options")
     val_options.add_argument("--read-aligner", metavar="PATH", type=str, default="minimap2", help="read aligner executable (only 'minimap2' is allowed) [minimap2]")
-    val_options.add_argument("-R", metavar="<reads.fasta>", type=str, default="", help="validation reads. gzipped fastq or fasta allowed.")
-    val_options.add_argument("-F", metavar="<reads.fofn>", type=str, default="", help="same as '-R', but a list of files.")
-    val_options.add_argument("-T", metavar="sr", type=str, default="", help="read type. 'sr' and 'corr' accepted for short reads and error corrected long-reads, respectively.")
+    val_options.add_argument("-R", metavar="<reads.fasta>", type=str, default="", help="validation reads (uncompressed or gzipped) [null]")
+    val_options.add_argument("-F", metavar="<reads.fofn>", type=str, default="", help="same as '-R', but a list of files [null]")
+    val_options.add_argument("-T", metavar="STR", type=str, default="", help="read type. 'sr' and 'corr' accepted for short reads and error corrected long-reads, respectively [null]")
     val_options.add_argument("-v", metavar="INT", type=int, default=10000, help="coverage validation window size [10000]")
     val_options.add_argument("--max-cov", metavar="INT", type=int, default=-1, help="break sequences at regions at or above this coverage level [AUTO]")
     val_options.add_argument("--min-cov", metavar="INT", type=int, default=-1, help="break sequences at regions at or below this coverage level [AUTO]")
@@ -367,10 +369,11 @@ def main():
 
     if not args.reference or not args.query:
         parser.print_help()
+        print("\n** The reference and query FASTA files are required **")
         sys.exit()
 
     log("RagTag " + get_ragtag_version())
-    log("CMD: " + " ".join(sys.argv))
+    log("CMD: ragtag.py correct " + " ".join(sys.argv[1:]))
 
     reference_file = os.path.abspath(args.reference)
     query_file = os.path.abspath(args.query)
@@ -396,6 +399,10 @@ def main():
         os.mkdir(output_path)
     output_path = os.path.abspath(output_path) + "/"
 
+    # Setup a log file for external RagTag scripts
+    ragtag_log = output_path + "ragtag.correct.err"
+    open(ragtag_log, "w").close()  # Wipe the log file
+
     overwrite_files = args.w
     remove_suffix = not args.u
     if remove_suffix:
@@ -510,7 +517,7 @@ def main():
     # If alignments are from Nucmer, convert from delta to paf.
     if genome_aligner == "nucmer":
         cmd = ["ragtag_delta2paf.py", output_path + "c_query_against_ref.delta"]
-        run_o(cmd, output_path + "c_query_against_ref.paf", )
+        run_oae(cmd, output_path + "c_query_against_ref.paf", ragtag_log)
 
     # Read and organize the alignments.
     log('Reading whole genome alignments')
@@ -625,7 +632,7 @@ def main():
 
     # Write the summary of query sequence breaks in AGP format
     agp_file = output_path + "ragtag.correction.agp"
-    write_breaks(agp_file, query_file, ctg_breaks, overwrite_files, remove_suffix)
+    write_breaks(agp_file, query_file, ctg_breaks, True, remove_suffix)
 
     # Write the scaffolds.
     log("Writing broken contigs")
@@ -636,7 +643,7 @@ def main():
         agp_file,
         query_file
     ]
-    run_o(cmd, output_path + qf_pref + ".corrected.fasta")
+    run_oae(cmd, output_path + qf_pref + ".corrected.fasta", ragtag_log)
 
     log("Goodbye")
 
