@@ -31,7 +31,7 @@ from collections import defaultdict
 
 import pysam
 
-from ragtag_utilities.utilities import log, run_o, get_ragtag_version
+from ragtag_utilities.utilities import log, run_oae, get_ragtag_version
 from ragtag_utilities.AlignmentReader import PAFReader
 from ragtag_utilities.ContigAlignment import ContigAlignment
 from ragtag_utilities.AGPFile import AGPFile
@@ -63,13 +63,16 @@ def write_orderings(out_agp_file, out_confidence_file, query_file, ordering_dict
             log("Retaining pre-existing file: " + out_agp_file)
             return
 
+        else:
+            log("Overwriting pre-existing file: " + out_agp_file)
+
     # Proceed with writing the intermediate output
     placed_seqs = set()
     all_out_cs_lines = []  # For confidence scores
-    agp = AGPFile(out_agp_file)
+    agp = AGPFile(out_agp_file, mode="w")
 
-    agp.add_comment("## agp-version 2.1")
-    agp.add_comment("# AGP created by RagTag")
+    agp.add_pragma()
+    agp.add_comment("# AGP created by RagTag {}".format(get_ragtag_version()))
 
     # Go through the reference sequences in sorted order
     sorted_ref_headers = sorted(list(ordering_dict.keys()))
@@ -192,6 +195,7 @@ def write_orderings(out_agp_file, out_confidence_file, query_file, ordering_dict
                 agp.add_seq_line(*out_agp_line)
 
     agp.write()
+    fai.close()
 
     # Write the confidence scores
     with open(out_confidence_file, "w") as f:
@@ -245,11 +249,13 @@ def read_genome_alignments(aln_file, query_blacklist, ref_blacklist):
 
 def main():
     parser = argparse.ArgumentParser(description='Reference-guided scaffolding', usage="ragtag.py scaffold <reference.fa> <query.fa>")
+
+    parser.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (uncompressed or bgzipped)")
+    parser.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (uncompressed or bgzipped)")
+
     scaf_options = parser.add_argument_group("scaffolding options")
-    scaf_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (can be uncompressed or bgzipped)")
-    scaf_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (can be uncompressed or bgzipped)")
-    scaf_options.add_argument("-e", metavar="<exclude.txt>", type=str, default="", help="list of reference headers to ignore")
-    scaf_options.add_argument("-j", metavar="<skip.txt>", type=str, default="", help="list of query headers to leave unplaced")
+    scaf_options.add_argument("-e", metavar="<exclude.txt>", type=str, default="", help="list of reference headers to ignore [null]")
+    scaf_options.add_argument("-j", metavar="<skip.txt>", type=str, default="", help="list of query headers to leave unplaced [null]")
     scaf_options.add_argument("-f", metavar="INT", type=int, default=1000, help="minimum unique alignment length [1000]")
     scaf_options.add_argument("--remove-small", action="store_true", default=False, help="remove unique alignments shorter than -f")
     scaf_options.add_argument("-q", metavar="INT", type=int, default=10, help="minimum mapq (NA for Nucmer alignments) [10]")
@@ -278,10 +284,11 @@ def main():
     args = parser.parse_args()
     if not args.reference or not args.query:
         parser.print_help()
+        print("\n** The reference and query FASTA files are required **")
         sys.exit()
 
     log("RagTag " + get_ragtag_version())
-    log("CMD: " + " ".join(sys.argv))
+    log("CMD: ragtag.py scaffold " + " ".join(sys.argv[1:]))
 
     reference_file = os.path.abspath(args.reference)
     query_file = os.path.abspath(args.query)
@@ -310,6 +317,10 @@ def main():
         os.mkdir(output_path)
     output_path = os.path.abspath(output_path) + "/"
 
+    # Setup a log file for external RagTag scripts
+    ragtag_log = output_path + "ragtag.scaffold.err"
+    open(ragtag_log, "w").close()  # Wipe the log file
+
     overwrite_files = args.w
     remove_suffix = not args.u
     if remove_suffix:
@@ -377,7 +388,7 @@ def main():
     # If alignments are from Nucmer, need to convert from delta to paf
     if aligner == "nucmer":
         cmd = ["ragtag_delta2paf.py", output_path + "query_against_ref.delta"]
-        run_o(cmd, output_path + "query_against_ref.paf", )
+        run_oae(cmd, output_path + "query_against_ref.paf", ragtag_log)
 
     # Read and organize the alignments
     log('Reading whole genome alignments')
@@ -503,7 +514,7 @@ def main():
 
     # Write the intermediate output file in AGP v2.1 format
     log("Writing: " + output_path + "ragtag.scaffolds.agp")
-    write_orderings(output_path + "ragtag.scaffolds.agp", output_path + "ragtag.confidence.txt", query_file, mapped_ref_seqs, fltrd_ctg_alns, pad_sizes, gap_types, make_chr0, overwrite_files, not remove_suffix)
+    write_orderings(output_path + "ragtag.scaffolds.agp", output_path + "ragtag.confidence.txt", query_file, mapped_ref_seqs, fltrd_ctg_alns, pad_sizes, gap_types, make_chr0, True, not remove_suffix)
 
     # Build a FASTA from the AGP
     cmd = [
@@ -511,7 +522,7 @@ def main():
         output_path + "ragtag.scaffolds.agp",
         query_file
     ]
-    run_o(cmd, output_path + "ragtag.scaffolds.fasta")
+    run_oae(cmd, output_path + "ragtag.scaffolds.fasta", ragtag_log)
 
     # Calculate the stats
     cmd = [
@@ -519,7 +530,7 @@ def main():
         output_path + "ragtag.scaffolds.agp",
         output_path + "ragtag.confidence.txt"
     ]
-    run_o(cmd, output_path + "ragtag.scaffolds.stats")
+    run_oae(cmd, output_path + "ragtag.scaffolds.stats", ragtag_log)
 
     log("Goodbye")
 
